@@ -1,6 +1,6 @@
 //
 // R package splines2 by Wenjie Wang and Jun Yan
-// Copyright (C) 2016-2023
+// Copyright (C) 2016-2025
 //
 // This file is part of the R package splines2.
 //
@@ -18,12 +18,17 @@
 #ifndef SPLINES2_ARMADILLO_H
 #define SPLINES2_ARMADILLO_H
 
+#ifndef ARMA_NO_DEBUG
+#define ARMA_NO_DEBUG
+#endif
+
 #include "splines2Armadillo/BSpline.h"
 #include "splines2Armadillo/MSpline.h"
 #include "splines2Armadillo/ISpline.h"
 #include "splines2Armadillo/CSpline.h"
 #include "splines2Armadillo/BernsteinPoly.h"
 #include "splines2Armadillo/NaturalSpline.h"
-#include "splines2Armadillo/PeriodicMSpline.h"
+#include "splines2Armadillo/NaturalSplineK.h"
+#include "splines2Armadillo/PeriodicSpline.h"
 
 #endif
