@@ -1,6 +1,6 @@
 //
 // R package splines2 by Wenjie Wang and Jun Yan
-// Copyright (C) 2016-2023
+// Copyright (C) 2016-2025
 //
 // This file is part of the R package splines2.
 //
@@ -124,6 +124,41 @@ namespace splines2 {
             }
         }
 
+        // helper to generate default internal knots
+        // goal: unique, inside boundary, of the specified length
+        inline rvec gen_default_internal_knots(
+            const rvec& x_inside,
+            const rvec& boundary_knots,
+            const unsigned int n_internal_knots) const
+        {
+            rvec prob_vec { linspace_inside(0, 1, n_internal_knots) };
+            // 1. set knots based on quantiles
+            // 2. check if 1) any duplicated, 2) coincide with boundary
+            // 3. set knots to have equal distance as the last resort
+            rvec internal_knots { quantile(x_inside, prob_vec) };
+            const bool any_dup { any_duplicated(internal_knots) };
+            if (any_dup) {
+                Rcpp::warning(
+                    "Set equidistant internal knots "
+                    "(found duplicated knots from quantiles).");
+                return linspace_inside(boundary_knots(0),
+                                       boundary_knots(1),
+                                       n_internal_knots);
+            }
+            // else
+            double min_int_knots { internal_knots(0) };
+            double max_int_knots { internal_knots(internal_knots.n_elem - 1) };
+            if (boundary_knots(0) >= min_int_knots ||
+                boundary_knots(1) <= max_int_knots) {
+                Rcpp::warning("Set equidistant internal knots "
+                              "(found on-boundary knots from quantiles)");
+                return linspace_inside(boundary_knots(0),
+                                       boundary_knots(1),
+                                       n_internal_knots);
+            }
+            return internal_knots;
+        }
+
         // compute spline df
         inline virtual void update_spline_df()
         {
@@ -135,7 +170,7 @@ namespace splines2 {
             const rvec& internal_knots,
             const rvec& boundary_knots,
             const unsigned int order
-            )
+            ) const
         {
             rvec out { arma::zeros(internal_knots.n_elem + 2 * order) };
             rvec::iterator it { out.begin() }, it_end { out.end() - 1 };
@@ -151,11 +186,8 @@ namespace splines2 {
         }
 
         // set simple knot sequence
-        inline virtual void update_simple_knot_sequence()
+        inline virtual void set_simple_knot_sequence()
         {
-            if (is_knot_sequence_latest_ && knot_sequence_.n_elem > 0) {
-                return;
-            }
             knot_sequence_ = get_simple_knot_sequence(
                 internal_knots_, boundary_knots_, order_
                 );
@@ -213,7 +245,7 @@ namespace splines2 {
                               surrogate_boundary_knots_(0)) &&
                 isAlmostEqual(boundary_knots_(1),
                               surrogate_boundary_knots_(1))
-                );
+                ) || has_internal_multiplicity_;
             // set flags to prevent knot sequence from being updated
             is_knot_sequence_latest_ = true;
         }
@@ -226,7 +258,7 @@ namespace splines2 {
             if (is_extended_knot_sequence_) {
                 set_extended_knot_sequence(knot_sequence_);
             } else {
-                update_simple_knot_sequence();
+                set_simple_knot_sequence();
             }
         }
 
@@ -254,10 +286,11 @@ namespace splines2 {
         // check if simple knot sequence
         inline virtual void stopifnot_simple_knot_sequence() const
         {
-            if (has_internal_multiplicity_ || is_extended_knot_sequence_) {
-                throw std::range_error(
-                    "Expected a simple knot sequence."
-                    );
+            if (has_internal_multiplicity_) {
+                throw std::range_error("Found duplicated internal knots");
+            }
+            if (is_extended_knot_sequence_) {
+                throw std::range_error("Expected a simple knot sequence.");
             }
         }
 
@@ -274,7 +307,7 @@ namespace splines2 {
             degree_ { pSplineBase->degree_  },
             knot_sequence_ { pSplineBase->knot_sequence_ },
             has_internal_multiplicity_ {
-                pSplineBase->is_knot_sequence_latest_ },
+                pSplineBase->has_internal_multiplicity_ },
             is_knot_sequence_latest_ {
                 pSplineBase->is_knot_sequence_latest_ },
             is_extended_knot_sequence_ {
@@ -289,6 +322,17 @@ namespace splines2 {
             order_ = degree_ + 1;
         }
 
+        // explicit conversion
+        template <typename T>
+        explicit operator T() const {
+            T obj;
+            obj.set_x(x_)->
+                set_degree(degree_)->
+                set_internal_knots(internal_knots_)->
+                set_boundary_knots(boundary_knots_);
+            return obj;
+        }
+
         // constructor with specificied internal_knots
         SplineBase(const rvec& x,
                    const rvec& internal_knots,
@@ -316,16 +360,11 @@ namespace splines2 {
             spline_df_ = spline_df;
             // determine internal knots by spline_df and x
             unsigned int n_internal_knots { spline_df_ - order_ };
-            if (n_internal_knots == 0) {
-                simplify_knots(rvec(), boundary_knots);
-            } else {
-                rvec prob_vec { arma::linspace(0, 1, n_internal_knots + 2) };
-                prob_vec = prob_vec.subvec(1, n_internal_knots);
-                simplify_knots(rvec(), boundary_knots);
-                // get quantiles of x within boundary only
+            simplify_knots(rvec(), boundary_knots);
+            if (n_internal_knots > 0) {
                 rvec x_inside { get_inside_x(x, boundary_knots_) };
-                rvec internal_knots { arma_quantile(x_inside, prob_vec) };
-                simplify_knots(internal_knots);
+                internal_knots_ = gen_default_internal_knots(
+                    x_inside, boundary_knots_, n_internal_knots);
             }
         }
 
@@ -395,6 +434,9 @@ namespace splines2 {
                 order_ = degree + 1;
                 update_spline_df();
                 if (is_extended_knot_sequence_) {
+                    // if a knot sequence has been set and it is extended,
+                    // update knot sequence
+                    // so that internal/boundary knots are update-to-date
                     set_extended_knot_sequence(knot_sequence_);
                 } else {
                     is_knot_sequence_latest_ = false;
@@ -411,7 +453,6 @@ namespace splines2 {
             }
             return this;
         }
-
         // "getter" functions
         inline rvec get_x() const
         {
@@ -443,6 +484,11 @@ namespace splines2 {
             update_spline_df();
             return spline_df_;
         }
+        inline uvec get_x_index()
+        {
+            update_x_index();
+            return x_index_;
+        }
 
         // define pure virtual functions
         inline virtual rmat basis(
