@@ -1,6 +1,7 @@
 ## get implementations of v0.2.8 for reference
 v2 <- new.env()
 source("../v0.2.8.R", v2)
+source("utils.R")
 
 ## helper functions
 isNumMatrix <- v2$isNumMatrix
@@ -10,23 +11,23 @@ isNumMatrix <- v2$isNumMatrix
 x <- seq.int(0, 1, 0.05)
 ord <- 4
 aKnots <- c(rep(0, ord), rep(1, ord))
-expect_equivalent(dbs(x, derivs = 1, intercept = TRUE),
-                  splines::splineDesign(aKnots, x = x, derivs = 1))
-expect_equivalent(dbs(x, derivs = 2, intercept = TRUE),
-                  splines::splineDesign(aKnots, x = x, derivs = 2))
+expect_eqt(dbs(x, derivs = 1, intercept = TRUE),
+           splines::splineDesign(aKnots, x = x, derivs = 1))
+expect_eqt(dbs(x, derivs = 2, intercept = TRUE),
+           splines::splineDesign(aKnots, x = x, derivs = 2))
 ## except at right boundary knots
-expect_equivalent(
+expect_eqt(
     dbs(x, derivs = 3, intercept = TRUE)[- length(x), ],
     splines::splineDesign(aKnots, derivs = 3, x = x)[- length(x), ]
 )
 
 knots <- c(0.2, 0.4, 0.7)
 aKnots <- c(rep(0, ord), na.omit(knots), rep(1, ord))
-expect_equivalent(dbs(x, derivs = 1, knots = knots, intercept = TRUE),
-                  splines::splineDesign(aKnots, x = x, derivs = 1))
-expect_equivalent(dbs(x, derivs = 2, knots = knots, intercept = TRUE),
-                  splines::splineDesign(aKnots, x = x, derivs = 2))
-expect_equivalent(
+expect_eqt(dbs(x, derivs = 1, knots = knots, intercept = TRUE),
+           splines::splineDesign(aKnots, x = x, derivs = 1))
+expect_eqt(dbs(x, derivs = 2, knots = knots, intercept = TRUE),
+           splines::splineDesign(aKnots, x = x, derivs = 2))
+expect_eqt(
     dbs(x, derivs = 3, knots = knots, intercept = TRUE)[- length(x), ],
     splines::splineDesign(aKnots, x = x, derivs = 3)[- length(x), ]
 )
@@ -35,13 +36,13 @@ knots <- c(0.3, 0.6)
 ord <- 5
 aKnots <- c(rep(0, ord), na.omit(knots), rep(1, ord))
 
-expect_equivalent(dbs(x, 1, knots = knots, degree = 4, intercept = TRUE),
-                  splines::splineDesign(aKnots, x, ord, derivs = 1))
-expect_equivalent(dbs(x, 2, knots = knots, degree = 4, intercept = TRUE),
-                  splines::splineDesign(aKnots, x, ord, derivs = 2))
-expect_equivalent(dbs(x, 3, knots = knots, degree = 4, intercept = TRUE),
-                  splines::splineDesign(aKnots, x, ord, derivs = 3))
-expect_equivalent(
+expect_eqt(dbs(x, 1, knots = knots, degree = 4, intercept = TRUE),
+           splines::splineDesign(aKnots, x, ord, derivs = 1))
+expect_eqt(dbs(x, 2, knots = knots, degree = 4, intercept = TRUE),
+           splines::splineDesign(aKnots, x, ord, derivs = 2))
+expect_eqt(dbs(x, 3, knots = knots, degree = 4, intercept = TRUE),
+           splines::splineDesign(aKnots, x, ord, derivs = 3))
+expect_eqt(
     dbs(x, 4, knots = knots, degree = 4, intercept = TRUE)[- length(x), ],
     splines::splineDesign(aKnots, x, ord, derivs = 4)[- length(x), ]
 )
@@ -69,37 +70,37 @@ x2 <- c(- 1, 2, x)
 b_knots <- c(0, 1)
 
 ## default cubic splines without internal knots
-expect_equivalent(dbs(x), v2$dbs(x))
+expect_eqt(dbs(x), v2$dbs(x))
 
 ## cubic splines with specified df
-expect_equivalent(dbs(x, df = 5),
-                  v2$dbs(x, df = 5))
+expect_eqt(dbs(x, df = 5),
+           v2$dbs(x, df = 5))
 
 ## cubic splines with specified internal knots
-expect_equivalent(dbs(x, knots = knots),
-                  v2$dbs(x, knots = knots))
+expect_eqt(dbs(x, knots = knots),
+           v2$dbs(x, knots = knots))
 
 ## qudractic splines without internal knots
-expect_equivalent(dbs(x, degree = 2L),
-                  v2$dbs(x, degree = 2L))
+expect_eqt(dbs(x, degree = 2L),
+           v2$dbs(x, degree = 2L))
 
 ## complete basis with intercept
-expect_equivalent(dbs(x, intercept = TRUE),
-                  v2$dbs(x, intercept = TRUE))
+expect_eqt(dbs(x, intercept = TRUE),
+           v2$dbs(x, intercept = TRUE))
 
 ## specified knots
-expect_equivalent(dbs(x, knots = knots, intercept = TRUE),
-                  v2$dbs(x, knots = knots, intercept = TRUE))
+expect_eqt(dbs(x, knots = knots, intercept = TRUE),
+           v2$dbs(x, knots = knots, intercept = TRUE))
 
 ## specified df
-expect_equivalent(dbs(x, df = 6, intercept = TRUE),
-                  v2$dbs(x, df = 6, intercept = TRUE))
+expect_eqt(dbs(x, df = 6, intercept = TRUE),
+           v2$dbs(x, df = 6, intercept = TRUE))
 
 ## degree zero
-expect_equivalent(dbs(x, df = 5, degree = 0),
-                  v2$dbs(x, df = 5, degree = 0))
-expect_equivalent(dbs(x, df = 5, degree = 0, intercept = TRUE),
-                  v2$dbs(x, df = 5, degree = 0, intercept = TRUE))
+expect_eqt(dbs(x, df = 5, degree = 0),
+           v2$dbs(x, df = 5, degree = 0))
+expect_eqt(dbs(x, df = 5, degree = 0, intercept = TRUE),
+           v2$dbs(x, df = 5, degree = 0, intercept = TRUE))
 bsMat0a <- dbs(x, degree = 0, intercept = TRUE)
 bsMat0b <- dbs(x, df = 5, degree = 0)
 bsMat0c <- dbs(x, df = 5, degree = 0, intercept = TRUE)
@@ -121,13 +122,13 @@ expect_true(isNumMatrix(
 
 ## x outside of boundary
 suppressWarnings({
-    expect_equivalent(
+    expect_eqt(
         dbs(x2, df = 6, degree = 3, Boundary.knots = b_knots),
         v2$dbs(x2, df = 6, degree = 3, Boundary.knots = b_knots)
     )
 })
 suppressWarnings({
-    expect_equivalent(
+    expect_eqt(
         dbs(x2, knots = knots, degree = 3, Boundary.knots = b_knots),
         v2$dbs(x2, knots = knots, degree = 3, Boundary.knots = b_knots)
     )
